@@ -25,36 +25,41 @@ def plugin(f, *args, **kwargs) -> None:  # type: ignore[no-untyped-def]
 
 def _log_sys_info() -> None:
 	# Log various information about hardware before starting the installation. This might assist in troubleshooting
-	debug(f"Hardware model detected: {SysInfo.sys_vendor()} {SysInfo.product_name()}; UEFI mode: {SysInfo.has_uefi()}")
-	debug(f"Processor model detected: {SysInfo.cpu_model()}")
-	debug(f"Memory statistics: {SysInfo.mem_available()} available out of {SysInfo.mem_total()} total installed")
-	debug(f"Virtualization detected: {SysInfo.virtualization()}; is VM: {SysInfo.is_vm()}")
-	debug(f"Graphics devices detected: {SysInfo._graphics_devices().keys()}")
+	debug(f'Hardware model detected: {SysInfo.sys_vendor()} {SysInfo.product_name()}; UEFI mode: {SysInfo.has_uefi()}')
+	debug(f'Processor model detected: {SysInfo.cpu_model()}')
+	debug(f'Memory statistics: {SysInfo.mem_available()} available out of {SysInfo.mem_total()} total installed')
+	debug(f'Virtualization detected: {SysInfo.virtualization()}; is VM: {SysInfo.is_vm()}')
+	debug(f'Graphics devices detected: {SysInfo._graphics_devices().keys()}')
 
 	# For support reasons, we'll log the disk layout pre installation to match against post-installation layout
-	debug(f"Disk states before installing:\n{disk_layouts()}")
+	debug(f'Disk states before installing:\n{disk_layouts()}')
 
 
 def _fetch_arch_db() -> None:
-	info("Fetching Arch Linux package database...")
+	info('Fetching Arch Linux package database...')
 	try:
-		Pacman.run("-Sy")
+		Pacman.run('-Sy')
 	except Exception as e:
-		debug(f"Failed to sync Arch Linux package database: {e}")
+		error('Failed to sync Arch Linux package database.')
+		if 'could not resolve host' in str(e).lower():
+			error('Most likely due to a missing network connection or DNS issue.')
+		error('Run archinstall --debug and check /var/log/archinstall/install.log for details.')
+
+		debug(f'Failed to sync Arch Linux package database: {e}')
 		exit(1)
 
 
 def _check_new_version() -> None:
-	info("Checking version...")
+	info('Checking version...')
 	upgrade = None
 
 	try:
-		upgrade = Pacman.run("-Qu archinstall").decode()
+		upgrade = Pacman.run('-Qu archinstall').decode()
 	except Exception as e:
-		debug(f"Failed determine pacman version: {e}")
+		debug(f'Failed determine pacman version: {e}')
 
 	if upgrade:
-		text = f"New version available: {upgrade}"
+		text = f'New version available: {upgrade}'
 		info(text)
 		time.sleep(3)
 
@@ -65,12 +70,12 @@ def main() -> int:
 	OR straight as a module: python -m archinstall
 	In any case we will be attempting to load the provided script to be run from the scripts/ folder
 	"""
-	if "--help" in sys.argv or "-h" in sys.argv:
+	if '--help' in sys.argv or '-h' in sys.argv:
 		arch_config_handler.print_help()
 		return 0
 
 	if os.getuid() != 0:
-		print(tr("Archinstall requires root privileges to run. See --help for more."))
+		print(tr('Archinstall requires root privileges to run. See --help for more.'))
 		return 1
 
 	_log_sys_info()
@@ -83,7 +88,7 @@ def main() -> int:
 
 	script = arch_config_handler.args.script
 
-	mod_name = f"archinstall.scripts.{script}"
+	mod_name = f'archinstall.scripts.{script}'
 	# by loading the module we'll automatically run the script
 	importlib.import_module(mod_name)
 
@@ -103,11 +108,11 @@ def run_as_a_module() -> None:
 		Tui.shutdown()
 
 		if exc:
-			err = "".join(traceback.format_exception(exc))
+			err = ''.join(traceback.format_exception(exc))
 			error(err)
 
 			text = (
-				"Archinstall experienced the above error. If you think this is a bug, please report it to\n"
+				'Archinstall experienced the above error. If you think this is a bug, please report it to\n'
 				'https://github.com/archlinux/archinstall and include the log file "/var/log/archinstall/install.log".\n\n'
 				"Hint: To extract the log from a live ISO \ncurl -F'file=@/var/log/archinstall/install.log' https://0x0.st\n"
 			)
@@ -119,19 +124,19 @@ def run_as_a_module() -> None:
 
 
 __all__ = [
-	"FormattedOutput",
-	"Language",
-	"Pacman",
-	"SysInfo",
-	"Tui",
-	"arch_config_handler",
-	"debug",
-	"disk_layouts",
-	"error",
-	"info",
-	"load_plugin",
-	"log",
-	"plugin",
-	"translation_handler",
-	"warn",
+	'FormattedOutput',
+	'Language',
+	'Pacman',
+	'SysInfo',
+	'Tui',
+	'arch_config_handler',
+	'debug',
+	'disk_layouts',
+	'error',
+	'info',
+	'load_plugin',
+	'log',
+	'plugin',
+	'translation_handler',
+	'warn',
 ]
