@@ -6,23 +6,23 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class CinnamonProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__("Cinnamon", ProfileType.DesktopEnv)
+		super().__init__('Cinnamon', ProfileType.DesktopEnv)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		return [
-			"cinnamon",
-			"system-config-printer",
-			"gnome-keyring",
-			"gnome-terminal",
-			"blueman",
-			"bluez-utils",
-			"engrampa",
-			"gnome-screenshot",
-			"gvfs-smb",
-			"xed",
-			"xdg-user-dirs-gtk",
+			'cinnamon',
+			'system-config-printer',
+			'gnome-keyring',
+			'gnome-terminal',
+			'blueman',
+			'bluez-utils',
+			'engrampa',
+			'gnome-screenshot',
+			'gvfs-smb',
+			'xed',
+			'xdg-user-dirs-gtk',
 		]
 
 	@property
