@@ -6,13 +6,13 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class CosmicProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__("cosmic-epoch", ProfileType.DesktopEnv, advanced=True)
+		super().__init__('cosmic-epoch', ProfileType.DesktopEnv, advanced=True)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		return [
-			"cosmic",
+			'cosmic',
 		]
 
 	@property
