@@ -23,27 +23,27 @@ from .output import debug, error
 from .storage import storage
 
 # https://stackoverflow.com/a/43627833/929999
-_VT100_ESCAPE_REGEX = r"\x1B\[[?0-9;]*[a-zA-Z]"
+_VT100_ESCAPE_REGEX = r'\x1B\[[?0-9;]*[a-zA-Z]'
 _VT100_ESCAPE_REGEX_BYTES = _VT100_ESCAPE_REGEX.encode()
 
 
 def generate_password(length: int = 64) -> str:
 	haystack = string.printable  # digits, ascii_letters, punctuation (!"#$[] etc) and whitespace
-	return "".join(secrets.choice(haystack) for _ in range(length))
+	return ''.join(secrets.choice(haystack) for _ in range(length))
 
 
 def locate_binary(name: str) -> str:
 	if path := which(name):
 		return path
-	raise RequirementError(f"Binary {name} does not exist.")
+	raise RequirementError(f'Binary {name} does not exist.')
 
 
 def clear_vt100_escape_codes(data: bytes) -> bytes:
-	return re.sub(_VT100_ESCAPE_REGEX_BYTES, b"", data)
+	return re.sub(_VT100_ESCAPE_REGEX_BYTES, b'', data)
 
 
 def clear_vt100_escape_codes_from_str(data: str) -> str:
-	return re.sub(_VT100_ESCAPE_REGEX, "", data)
+	return re.sub(_VT100_ESCAPE_REGEX, '', data)
 
 
 def jsonify(obj: object, safe: bool = True) -> object:
@@ -57,11 +57,11 @@ def jsonify(obj: object, safe: bool = True) -> object:
 		return {
 			key: jsonify(value, safe)
 			for key, value in obj.items()
-			if isinstance(key, compatible_types) and not (isinstance(key, str) and key.startswith("!") and safe)
+			if isinstance(key, compatible_types) and not (isinstance(key, str) and key.startswith('!') and safe)
 		}
 	if isinstance(obj, Enum):
 		return obj.value
-	if hasattr(obj, "json"):
+	if hasattr(obj, 'json'):
 		# json() is a friendly name for json-helper, it should return
 		# a dictionary representation of the object so that it can be
 		# processed by the json library.
@@ -72,7 +72,7 @@ def jsonify(obj: object, safe: bool = True) -> object:
 		return [jsonify(item, safe) for item in obj]
 	if isinstance(obj, Path):
 		return str(obj)
-	if hasattr(obj, "__dict__"):
+	if hasattr(obj, '__dict__'):
 		return vars(obj)
 
 	return obj
@@ -104,26 +104,26 @@ class SysCommandWorker:
 		cmd: str | list[str],
 		peek_output: bool | None = False,
 		environment_vars: dict[str, str] | None = None,
-		working_directory: str | None = "./",
+		working_directory: str | None = './',
 		remove_vt100_escape_codes_from_lines: bool = True,
 	):
 		if isinstance(cmd, str):
 			cmd = shlex.split(cmd)
 
-		if cmd and not cmd[0].startswith(("/", "./")):  # Path() does not work well
+		if cmd and not cmd[0].startswith(('/', './')):  # Path() does not work well
 			cmd[0] = locate_binary(cmd[0])
 
 		self.cmd = cmd
 		self.peek_output = peek_output
 		# define the standard locale for command outputs. For now the C ascii one. Can be overridden
-		self.environment_vars = {"LC_ALL": "C"}
+		self.environment_vars = {'LC_ALL': 'C'}
 		if environment_vars:
 			self.environment_vars.update(environment_vars)
 
 		self.working_directory = working_directory
 
 		self.exit_code: int | None = None
-		self._trace_log = b""
+		self._trace_log = b''
 		self._trace_log_pos = 0
 		self.poll_object = epoll()
 		self.child_fd: int | None = None
@@ -146,13 +146,13 @@ class SysCommandWorker:
 		return False
 
 	def __iter__(self, *args: str, **kwargs: dict[str, Any]) -> Iterator[bytes]:
-		last_line = self._trace_log.rfind(b"\n")
+		last_line = self._trace_log.rfind(b'\n')
 		lines = filter(None, self._trace_log[self._trace_log_pos : last_line].splitlines())
 		for line in lines:
 			if self.remove_vt100_escape_codes_from_lines:
 				line = clear_vt100_escape_codes(line)
 
-			yield line + b"\n"
+			yield line + b'\n'
 
 		self._trace_log_pos = last_line
 
@@ -164,11 +164,11 @@ class SysCommandWorker:
 	@override
 	def __str__(self) -> str:
 		try:
-			return self._trace_log.decode("utf-8")
+			return self._trace_log.decode('utf-8')
 		except UnicodeDecodeError:
 			return str(self._trace_log)
 
-	def __enter__(self) -> "SysCommandWorker":
+	def __enter__(self) -> 'SysCommandWorker':
 		return self
 
 	def __exit__(self, *args: str) -> None:
@@ -184,7 +184,7 @@ class SysCommandWorker:
 		if self.peek_output:
 			# To make sure any peaked output didn't leave us hanging
 			# on the same line we were on.
-			sys.stdout.write("\n")
+			sys.stdout.write('\n')
 			sys.stdout.flush()
 
 		if len(args) >= 2 and args[1]:
@@ -192,7 +192,7 @@ class SysCommandWorker:
 
 		if self.exit_code != 0:
 			raise SysCallError(
-				f"{self.cmd} exited with abnormal exit code [{self.exit_code}]: {str(self)[-500:]}",
+				f'{self.cmd} exited with abnormal exit code [{self.exit_code}]: {str(self)[-500:]}',
 				self.exit_code,
 				worker_log=self._trace_log,
 			)
@@ -211,7 +211,7 @@ class SysCommandWorker:
 		self.make_sure_we_are_executing()
 
 		if self.child_fd:
-			return os.write(self.child_fd, data + (b"\n" if line_ending else b""))
+			return os.write(self.child_fd, data + (b'\n' if line_ending else b''))
 
 		return 0
 
@@ -233,17 +233,17 @@ class SysCommandWorker:
 		if self.peek_output:
 			if isinstance(output, bytes):
 				try:
-					output = output.decode("UTF-8")
+					output = output.decode('UTF-8')
 				except UnicodeDecodeError:
 					return False
 
-			peak_logfile = Path(f"{storage['LOG_PATH']}/cmd_output.txt")
+			peak_logfile = Path(f'{storage["LOG_PATH"]}/cmd_output.txt')
 
 			change_perm = False
 			if peak_logfile.exists() is False:
 				change_perm = True
 
-			with peak_logfile.open("a") as peek_output_log:
+			with peak_logfile.open('a') as peek_output_log:
 				peek_output_log.write(str(output))
 
 			if change_perm:
@@ -301,7 +301,7 @@ class SysCommandWorker:
 			try:
 				os.execve(self.cmd[0], list(self.cmd), {**os.environ, **self.environment_vars})
 			except FileNotFoundError:
-				error(f"{self.cmd[0]} does not exist.")
+				error(f'{self.cmd[0]} does not exist.')
 				self.exit_code = 1
 				return False
 		else:
@@ -313,7 +313,7 @@ class SysCommandWorker:
 
 		return True
 
-	def decode(self, encoding: str = "UTF-8") -> str:
+	def decode(self, encoding: str = 'UTF-8') -> str:
 		return self._trace_log.decode(encoding)
 
 
@@ -323,7 +323,7 @@ class SysCommand:
 		cmd: str | list[str],
 		peek_output: bool | None = False,
 		environment_vars: dict[str, str] | None = None,
-		working_directory: str | None = "./",
+		working_directory: str | None = './',
 		remove_vt100_escape_codes_from_lines: bool = True,
 	):
 		self.cmd = cmd
@@ -351,7 +351,7 @@ class SysCommand:
 
 	def __getitem__(self, key: slice) -> bytes | None:
 		if not self.session:
-			raise KeyError("SysCommand() does not have an active session.")
+			raise KeyError('SysCommand() does not have an active session.')
 		elif type(key) is slice:
 			start = key.start or 0
 			end = key.stop or len(self.session._trace_log)
@@ -362,7 +362,7 @@ class SysCommand:
 
 	@override
 	def __repr__(self, *args: list[Any], **kwargs: dict[str, Any]) -> str:
-		return self.decode("UTF-8", errors="backslashreplace") or ""
+		return self.decode('UTF-8', errors='backslashreplace') or ''
 
 	def create_session(self) -> bool:
 		"""
@@ -386,14 +386,14 @@ class SysCommand:
 				self.session.poll()
 
 		if self.peek_output:
-			sys.stdout.write("\n")
+			sys.stdout.write('\n')
 			sys.stdout.flush()
 
 		return True
 
-	def decode(self, encoding: str = "utf-8", errors: str = "backslashreplace", strip: bool = True) -> str:
+	def decode(self, encoding: str = 'utf-8', errors: str = 'backslashreplace', strip: bool = True) -> str:
 		if not self.session:
-			raise ValueError("No session available to decode")
+			raise ValueError('No session available to decode')
 
 		val = self.session._trace_log.decode(encoding, errors=errors)
 
@@ -403,10 +403,10 @@ class SysCommand:
 
 	def output(self, remove_cr: bool = True) -> bytes:
 		if not self.session:
-			raise ValueError("No session available")
+			raise ValueError('No session available')
 
 		if remove_cr:
-			return self.session._trace_log.replace(b"\r\n", b"\n")
+			return self.session._trace_log.replace(b'\r\n', b'\n')
 
 		return self.session._trace_log
 
@@ -425,15 +425,15 @@ class SysCommand:
 
 
 def _log_cmd(cmd: list[str]) -> None:
-	history_logfile = Path(f"{storage['LOG_PATH']}/cmd_history.txt")
+	history_logfile = Path(f'{storage["LOG_PATH"]}/cmd_history.txt')
 
 	change_perm = False
 	if history_logfile.exists() is False:
 		change_perm = True
 
 	try:
-		with history_logfile.open("a") as cmd_log:
-			cmd_log.write(f"{time.time()} {cmd}\n")
+		with history_logfile.open('a') as cmd_log:
+			cmd_log.write(f'{time.time()} {cmd}\n')
 
 		if change_perm:
 			history_logfile.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
@@ -459,6 +459,6 @@ def run(
 
 def _pid_exists(pid: int) -> bool:
 	try:
-		return any(subprocess.check_output(["ps", "--no-headers", "-o", "pid", "-p", str(pid)]).strip())
+		return any(subprocess.check_output(['ps', '--no-headers', '-o', 'pid', '-p', str(pid)]).strip())
 	except subprocess.CalledProcessError:
 		return False
