@@ -17,10 +17,10 @@ from ..utils.util import get_password
 class UserList(ListManager[User]):
 	def __init__(self, prompt: str, lusers: list[User]):
 		self._actions = [
-			tr("Add a user"),
-			tr("Change password"),
-			tr("Promote/Demote user"),
-			tr("Delete User"),
+			tr('Add a user'),
+			tr('Change password'),
+			tr('Promote/Demote user'),
+			tr('Delete User'),
 		]
 
 		super().__init__(
@@ -44,8 +44,8 @@ class UserList(ListManager[User]):
 				data = [d for d in data if d.username != new_user.username]
 				data += [new_user]
 		elif action == self._actions[1] and entry:  # change password
-			header = f"{tr('User')}: {entry.username}\n"
-			new_password = get_password(tr("Password"), header=header)
+			header = f'{tr("User")}: {entry.username}\n'
+			new_password = get_password(tr('Password'), header=header)
 
 			if new_password:
 				user = next(filter(lambda x: x == entry, data))
@@ -59,13 +59,13 @@ class UserList(ListManager[User]):
 		return data
 
 	def _check_for_correct_username(self, username: str) -> str | None:
-		if re.match(r"^[a-z_][a-z0-9_-]*\$?$", username) and len(username) <= 32:
+		if re.match(r'^[a-z_][a-z0-9_-]*\$?$', username) and len(username) <= 32:
 			return None
-		return tr("The username you entered is invalid")
+		return tr('The username you entered is invalid')
 
 	def _add_user(self) -> User | None:
 		editResult = EditMenu(
-			tr("Username"),
+			tr('Username'),
 			allow_skip=True,
 			validator=self._check_for_correct_username,
 		).input()
@@ -76,16 +76,16 @@ class UserList(ListManager[User]):
 			case ResultType.Selection:
 				username = editResult.text()
 			case _:
-				raise ValueError("Unhandled result type")
+				raise ValueError('Unhandled result type')
 
-		header = f"{tr('Username')}: {username}\n"
+		header = f'{tr("Username")}: {username}\n'
 
-		password = get_password(tr("Password"), header=header, allow_skip=True)
+		password = get_password(tr('Password'), header=header, allow_skip=True)
 
 		if not password:
 			return None
 
-		header += f"{tr('Password')}: {password.hidden()}\n\n"
+		header += f'{tr("Password")}: {password.hidden()}\n\n'
 		header += str(tr('Should "{}" be a superuser (sudo)?\n')).format(username)
 
 		group = MenuItemGroup.yes_no()
@@ -105,11 +105,11 @@ class UserList(ListManager[User]):
 			case ResultType.Selection:
 				sudo = result.item() == MenuItem.yes()
 			case _:
-				raise ValueError("Unhandled result type")
+				raise ValueError('Unhandled result type')
 
 		return User(username, password, sudo)
 
 
-def ask_for_additional_users(prompt: str = "", defined_users: list[User] = []) -> list[User]:
+def ask_for_additional_users(prompt: str = '', defined_users: list[User] = []) -> list[User]:
 	users = UserList(prompt, defined_users).run()
 	return users
