@@ -13,18 +13,18 @@ if TYPE_CHECKING:
 
 
 class NicType(Enum):
-	ISO = "iso"
-	NM = "nm"
-	MANUAL = "manual"
+	ISO = 'iso'
+	NM = 'nm'
+	MANUAL = 'manual'
 
 	def display_msg(self) -> str:
 		match self:
 			case NicType.ISO:
-				return tr("Copy ISO network configuration to installation")
+				return tr('Copy ISO network configuration to installation')
 			case NicType.NM:
-				return tr("Use NetworkManager (necessary to configure internet graphically in GNOME and KDE Plasma)")
+				return tr('Use NetworkManager (necessary to configure internet graphically in GNOME and KDE Plasma)')
 			case NicType.MANUAL:
-				return tr("Manual configuration")
+				return tr('Manual configuration')
 
 
 class _NicSerialization(TypedDict):
@@ -45,30 +45,30 @@ class Nic:
 
 	def table_data(self) -> dict[str, str | bool | list[str]]:
 		return {
-			"iface": self.iface if self.iface else "",
-			"ip": self.ip if self.ip else "",
-			"dhcp": self.dhcp,
-			"gateway": self.gateway if self.gateway else "",
-			"dns": self.dns,
+			'iface': self.iface if self.iface else '',
+			'ip': self.ip if self.ip else '',
+			'dhcp': self.dhcp,
+			'gateway': self.gateway if self.gateway else '',
+			'dns': self.dns,
 		}
 
 	def json(self) -> _NicSerialization:
 		return {
-			"iface": self.iface,
-			"ip": self.ip,
-			"dhcp": self.dhcp,
-			"gateway": self.gateway,
-			"dns": self.dns,
+			'iface': self.iface,
+			'ip': self.ip,
+			'dhcp': self.dhcp,
+			'gateway': self.gateway,
+			'dns': self.dns,
 		}
 
 	@staticmethod
 	def parse_arg(arg: _NicSerialization) -> Nic:
 		return Nic(
-			iface=arg.get("iface", None),
-			ip=arg.get("ip", None),
-			dhcp=arg.get("dhcp", True),
-			gateway=arg.get("gateway", None),
-			dns=arg.get("dns", []),
+			iface=arg.get('iface', None),
+			ip=arg.get('ip', None),
+			dhcp=arg.get('dhcp', True),
+			gateway=arg.get('gateway', None),
+			dns=arg.get('dns', []),
 		)
 
 	def as_systemd_config(self) -> str:
@@ -76,25 +76,25 @@ class Nic:
 		network: list[tuple[str, str]] = []
 
 		if self.iface:
-			match.append(("Name", self.iface))
+			match.append(('Name', self.iface))
 
 		if self.dhcp:
-			network.append(("DHCP", "yes"))
+			network.append(('DHCP', 'yes'))
 		else:
 			if self.ip:
-				network.append(("Address", self.ip))
+				network.append(('Address', self.ip))
 			if self.gateway:
-				network.append(("Gateway", self.gateway))
+				network.append(('Gateway', self.gateway))
 			for dns in self.dns:
-				network.append(("DNS", dns))
+				network.append(('DNS', dns))
 
-		config = {"Match": match, "Network": network}
+		config = {'Match': match, 'Network': network}
 
-		config_str = ""
+		config_str = ''
 		for top, entries in config.items():
-			config_str += f"[{top}]\n"
-			config_str += "\n".join([f"{k}={v}" for k, v in entries])
-			config_str += "\n\n"
+			config_str += f'[{top}]\n'
+			config_str += '\n'.join([f'{k}={v}' for k, v in entries])
+			config_str += '\n\n'
 
 		return config_str
 
@@ -110,15 +110,15 @@ class NetworkConfiguration:
 	nics: list[Nic] = field(default_factory=list)
 
 	def json(self) -> _NetworkConfigurationSerialization:
-		config: _NetworkConfigurationSerialization = {"type": self.type.value}
+		config: _NetworkConfigurationSerialization = {'type': self.type.value}
 		if self.nics:
-			config["nics"] = [n.json() for n in self.nics]
+			config['nics'] = [n.json() for n in self.nics]
 
 		return config
 
 	@staticmethod
 	def parse_arg(config: _NetworkConfigurationSerialization) -> NetworkConfiguration | None:
-		nic_type = config.get("type", None)
+		nic_type = config.get('type', None)
 		if not nic_type:
 			return None
 
@@ -128,7 +128,7 @@ class NetworkConfiguration:
 			case NicType.NM:
 				return NetworkConfiguration(NicType.NM)
 			case NicType.MANUAL:
-				nics_arg = config.get("nics", [])
+				nics_arg = config.get('nics', [])
 				if nics_arg:
 					nics = [Nic.parse_arg(n) for n in nics_arg]
 					return NetworkConfiguration(NicType.MANUAL, nics)
@@ -146,14 +146,14 @@ class NetworkConfiguration:
 					enable_services=True,  # Sources the ISO network configuration to the install medium.
 				)
 			case NicType.NM:
-				installation.add_additional_packages(["networkmanager"])
+				installation.add_additional_packages(['networkmanager'])
 				if profile_config and profile_config.profile:
 					if profile_config.profile.is_desktop_profile():
-						installation.add_additional_packages(["network-manager-applet"])
-				installation.enable_service("NetworkManager.service")
+						installation.add_additional_packages(['network-manager-applet'])
+				installation.enable_service('NetworkManager.service')
 			case NicType.MANUAL:
 				for nic in self.nics:
 					installation.configure_nic(nic)
 
-				installation.enable_service("systemd-networkd")
-				installation.enable_service("systemd-resolved")
+				installation.enable_service('systemd-networkd')
+				installation.enable_service('systemd-resolved')
