@@ -51,11 +51,11 @@ class AbstractCurses[ValueT](metaclass=ABCMeta):
 	def clear_help_win(self) -> None:
 		self._help_window.erase()
 
-	def _set_help_viewport(self) -> "Viewport":
+	def _set_help_viewport(self) -> 'Viewport':
 		max_height, max_width = Tui.t().max_yx
 		height = max_height - 10
 
-		max_help_width = max([len(line) for line in Help.get_help_text().split("\n")])
+		max_help_width = max([len(line) for line in Help.get_help_text().split('\n')])
 		x_start = int((max_width / 2) - (max_help_width / 2))
 
 		return Viewport(
@@ -63,7 +63,7 @@ class AbstractCurses[ValueT](metaclass=ABCMeta):
 			height,
 			x_start,
 			int((max_height / 2) - height / 2),
-			frame=FrameProperties.min(tr("Archinstall help")),
+			frame=FrameProperties.min(tr('Archinstall help')),
 		)
 
 	def _confirm_interrupt(self, warning: str) -> bool:
@@ -84,23 +84,23 @@ class AbstractCurses[ValueT](metaclass=ABCMeta):
 			return False
 
 	def help_entry(self) -> ViewportEntry:
-		return ViewportEntry(tr("Press Ctrl+h for help"), 0, 0, STYLE.NORMAL)
+		return ViewportEntry(tr('Press Ctrl+h for help'), 0, 0, STYLE.NORMAL)
 
 	def _show_help(self) -> None:
 		if not self._help_window:
-			debug("no help window set")
+			debug('no help window set')
 			return
 
 		help_text = Help.get_help_text()
-		lines = help_text.split("\n")
+		lines = help_text.split('\n')
 
-		entries = [ViewportEntry("", 0, 0, STYLE.NORMAL)]
-		entries += [ViewportEntry(f"   {e}   ", idx + 1, 0, STYLE.NORMAL) for idx, e in enumerate(lines)]
+		entries = [ViewportEntry('', 0, 0, STYLE.NORMAL)]
+		entries += [ViewportEntry(f'   {e}   ', idx + 1, 0, STYLE.NORMAL) for idx, e in enumerate(lines)]
 		self._help_window.update(entries, 0)
 
 	def get_header_entries(self, header: str) -> list[ViewportEntry]:
 		full_header = []
-		rows = header.split("\n")
+		rows = header.split('\n')
 
 		for cur_row, line in enumerate(rows):
 			full_header += [ViewportEntry(line, cur_row, 0, STYLE.NORMAL)]
@@ -191,7 +191,7 @@ class AbstractViewport:
 		frame: FrameProperties,
 		scroll_percentage: int | None = None,
 	) -> ViewportEntry:
-		top = self._replace_str(h_bar, 1, f" {frame.header} ") if frame.header else h_bar
+		top = self._replace_str(h_bar, 1, f' {frame.header} ') if frame.header else h_bar
 
 		if scroll_percentage is None:
 			top = Chars.Upper_left + top + Chars.Upper_right
@@ -220,7 +220,7 @@ class AbstractViewport:
 		max_height: int,
 		frame: FrameProperties,
 	) -> _FrameDim:
-		rows = self._assemble_entries(entries).split("\n")
+		rows = self._assemble_entries(entries).split('\n')
 		header_len = len(frame.header) if frame.header else 0
 		header_len += 3  # for header padding
 
@@ -266,23 +266,23 @@ class AbstractViewport:
 			return 0
 		return max(values)
 
-	def _replace_str(self, text: str, index: int = 0, replacement: str = "") -> str:
+	def _replace_str(self, text: str, index: int = 0, replacement: str = '') -> str:
 		len_replace = len(replacement)
-		return f"{text[:index]}{replacement}{text[index + len_replace :]}"
+		return f'{text[:index]}{replacement}{text[index + len_replace :]}'
 
 	def _assemble_entries(self, entries: list[ViewportEntry]) -> str:
 		if not entries:
-			return ""
+			return ''
 
 		max_col = self._max_col(entries)
-		view = [max_col * " "] * self._num_unique_rows(entries)
+		view = [max_col * ' '] * self._num_unique_rows(entries)
 
 		for e in entries:
 			view[e.row] = self._replace_str(view[e.row], e.col, e.text)
 
 		view = [v.rstrip() for v in view]
 
-		return "\n".join(view)
+		return '\n'.join(view)
 
 
 class EditViewport(AbstractViewport):
@@ -340,7 +340,7 @@ class EditViewport(AbstractViewport):
 		self._main_win.erase()
 
 		framed = self.add_frame(
-			[ViewportEntry("", 0, 0, STYLE.NORMAL)],
+			[ViewportEntry('', 0, 0, STYLE.NORMAL)],
 			self._edit_width,
 			3,
 			frame=self._frame,
@@ -486,9 +486,9 @@ class EditMenu(AbstractCurses[str]):
 		self._hide_input = hide_input
 
 		if self._interrupt_warning is None:
-			self._interrupt_warning = tr("Are you sure you want to reset this setting?") + "\n"
+			self._interrupt_warning = tr('Are you sure you want to reset this setting?') + '\n'
 
-		title = f"* {title}" if not self._allow_skip else title
+		title = f'* {title}' if not self._allow_skip else title
 		self._frame = FrameProperties(title, FrameStyle.MAX)
 
 		self._help_vp: Viewport | None = None
@@ -497,13 +497,13 @@ class EditMenu(AbstractCurses[str]):
 		self._info_vp: Viewport | None = None
 
 		self._set_default_info = True
-		self._only_ascii_text = ViewportEntry(tr("Only ASCII characters are supported"), 0, 0, STYLE.NORMAL)
+		self._only_ascii_text = ViewportEntry(tr('Only ASCII characters are supported'), 0, 0, STYLE.NORMAL)
 
 		self._init_viewports()
 
 		self._last_state: Result[str] | None = None
 		self._help_active = False
-		self._real_input = default_text or ""
+		self._real_input = default_text or ''
 
 	def _init_viewports(self) -> None:
 		y_offset = 0
@@ -567,7 +567,7 @@ class EditMenu(AbstractCurses[str]):
 				entry = ViewportEntry(err, 0, 0, STYLE.ERROR)
 				self._info_vp.update([entry], 0)
 				self._set_default_info = False
-				self._real_input = ""
+				self._real_input = ''
 				return None
 
 		return text
@@ -637,9 +637,6 @@ class EditMenu(AbstractCurses[str]):
 					self._show_help()
 					return None
 				case MenuKeys.ESC:
-					if self._help_active:
-						self._help_active = False
-						self._draw()
 					if self._allow_skip:
 						self._last_state = Result(ResultType.Skip, None)
 						key = 7
@@ -686,19 +683,19 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		column_spacing: int = 10,
 		header: str | None = None,
 		frame: FrameProperties | None = None,
-		cursor_char: str = ">",
+		cursor_char: str = '>',
 		search_enabled: bool = True,
 		allow_skip: bool = False,
 		allow_reset: bool = False,
 		reset_warning_msg: str | None = None,
 		preview_style: PreviewStyle = PreviewStyle.NONE,
-		preview_size: float | Literal["auto"] = 0.2,
+		preview_size: float | Literal['auto'] = 0.2,
 		preview_frame: FrameProperties | None = None,
 	):
 		super().__init__()
 
 		self._multi = multi
-		self._cursor_char = f"{cursor_char} "
+		self._cursor_char = f'{cursor_char} '
 		self._search_enabled = search_enabled
 		self._allow_skip = allow_skip
 		self._allow_reset = allow_reset
@@ -723,7 +720,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 			self._header_entries = self.get_header_entries(header)
 
 		if self._interrupt_warning is None:
-			self._interrupt_warning = tr("Are you sure you want to reset this setting?") + "\n"
+			self._interrupt_warning = tr('Are you sure you want to reset this setting?') + '\n'
 
 		if self._orientation == Orientation.HORIZONTAL:
 			self._horizontal_cols = columns
@@ -744,7 +741,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		self._init_viewports(preview_size)
 
 		assert self._menu_vp is not None
-		self._items_state: MenuItemsState = MenuItemsState(
+		self._items_state: MenuItemsState = MenuItemsState(  # type: ignore[unreachable]
 			self._item_group,
 			total_cols=self._horizontal_cols,
 			total_rows=self._menu_vp.height,
@@ -798,11 +795,11 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 	def _footer_entries(self) -> list[ViewportEntry]:
 		if self._active_search:
 			filter_pattern = self._item_group.filter_pattern
-			return [ViewportEntry(f"/{filter_pattern}", 0, 0, STYLE.NORMAL)]
+			return [ViewportEntry(f'/{filter_pattern}', 0, 0, STYLE.NORMAL)]
 
 		return []
 
-	def _init_viewports(self, arg_prev_size: float | Literal["auto"]) -> None:
+	def _init_viewports(self, arg_prev_size: float | Literal['auto']) -> None:
 		footer_height = 2  # possible filter at the bottom
 		y_offset = 0
 
@@ -900,15 +897,15 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 
 	def _determine_prev_size(
 		self,
-		preview_size: float | Literal["auto"],
+		preview_size: float | Literal['auto'],
 		offset: int = 0,
 	) -> int:
-		if not isinstance(preview_size, float) and preview_size != "auto":
+		if not isinstance(preview_size, float) and preview_size != 'auto':
 			raise ValueError('preview size must be a float or "auto"')
 
 		prev_size: int = 0
 
-		if preview_size == "auto":
+		if preview_size == 'auto':
 			match self._preview_style:
 				case PreviewStyle.RIGHT:
 					menu_width = self._item_group.get_max_width() + 5
@@ -984,7 +981,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 			cur_pos = len(self._cursor_char)
 
 			for col_idx, cell in enumerate(row):
-				cur_text = ""
+				cur_text = ''
 				style = STYLE.NORMAL
 
 				if cell == self._item_group.focus_item:
@@ -999,7 +996,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 
 				if col_idx < len(row) - 1:
 					spacer_len = cols_widths[col_idx] - len(menu_item_text)
-					entries += [ViewportEntry(" " * spacer_len, row_idx, cur_pos, STYLE.NORMAL)]
+					entries += [ViewportEntry(' ' * spacer_len, row_idx, cur_pos, STYLE.NORMAL)]
 					cur_pos += spacer_len
 
 		return entries
@@ -1019,7 +1016,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 		return col_widths
 
 	def _menu_item_text(self, item: MenuItem) -> str:
-		item_text = ""
+		item_text = ''
 
 		if self._multi and not item.is_empty():
 			item_text += self._multi_prefix(item)
@@ -1043,7 +1040,7 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 			self._preview_vp.update([])
 			return
 
-		preview_text = action_text.split("\n")
+		preview_text = action_text.split('\n')
 		entries = [ViewportEntry(e, idx, 0, STYLE.NORMAL) for idx, e in enumerate(preview_text)]
 
 		total_prev_rows = max([e.row for e in entries]) + 1  # rows start with 0 and we need the count
@@ -1109,11 +1106,11 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 
 	def _multi_prefix(self, item: MenuItem) -> str:
 		if item.read_only:
-			return "    "
+			return '    '
 		elif self._item_group.is_item_selected(item):
-			return "[x] "
+			return '[x] '
 		else:
-			return "[ ] "
+			return '[ ] '
 
 	def _handle_interrupt(self) -> bool:
 		if self._allow_reset and self._interrupt_warning:
@@ -1147,8 +1144,8 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 
 		if len(key_handles) > 1:
 			decoded = MenuKeys.decode(key)
-			handles = ", ".join([k.name for k in key_handles])
-			raise ValueError(f"Multiple key matches for key {decoded}: {handles}")
+			handles = ', '.join([k.name for k in key_handles])
+			raise ValueError(f'Multiple key matches for key {decoded}: {handles}')
 		elif len(key_handles) == 0:
 			return None
 
@@ -1178,24 +1175,24 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 
 					return None
 			case MenuKeys.MENU_DOWN | MenuKeys.MENU_RIGHT:
-				self._focus_item("next")
+				self._focus_item('next')
 			case MenuKeys.MENU_UP | MenuKeys.MENU_LEFT:
-				self._focus_item("prev")
+				self._focus_item('prev')
 			case MenuKeys.MENU_START:
-				self._focus_item("first")
+				self._focus_item('first')
 			case MenuKeys.MENU_END:
-				self._focus_item("last")
+				self._focus_item('last')
 			case MenuKeys.MULTI_SELECT:
 				if self._multi:
 					self._item_group.select_current_item()
 			case MenuKeys.ENABLE_SEARCH:
 				if self._search_enabled and not self._active_search:
 					self._active_search = True
-					self._item_group.set_filter_pattern("")
+					self._item_group.set_filter_pattern('')
 			case MenuKeys.ESC:
 				if self._active_search:
 					self._active_search = False
-					self._item_group.set_filter_pattern("")
+					self._item_group.set_filter_pattern('')
 				else:
 					if self._allow_skip:
 						return Result(ResultType.Skip, None)
@@ -1210,19 +1207,19 @@ class SelectMenu[ValueT](AbstractCurses[ValueT]):
 
 		return None
 
-	def _focus_item(self, direction: Literal["next", "prev", "first", "last"]) -> None:
+	def _focus_item(self, direction: Literal['next', 'prev', 'first', 'last']) -> None:
 		# reset the preview scroll as the newly focused item
 		# may have a different preview row count and it'll blow up
 		self._prev_scroll_pos = 0
 
 		match direction:
-			case "next":
+			case 'next':
 				self._item_group.focus_next()
-			case "prev":
+			case 'prev':
 				self._item_group.focus_prev()
-			case "first":
+			case 'first':
 				self._item_group.focus_first()
-			case "last":
+			case 'last':
 				self._item_group.focus_last()
 
 
@@ -1242,7 +1239,7 @@ class Tui:
 		return self._screen
 
 	@staticmethod
-	def t() -> "Tui":
+	def t() -> 'Tui':
 		assert Tui._t is not None
 		return Tui._t
 
@@ -1253,7 +1250,7 @@ class Tui:
 
 		Tui.t().stop()
 
-	def init(self) -> "Tui":
+	def init(self) -> 'Tui':
 		self._screen = curses.initscr()
 		curses.noecho()
 		curses.cbreak()
@@ -1295,11 +1292,11 @@ class Tui:
 		text: str,
 		row: int = 0,
 		col: int = 0,
-		endl: str | None = "\n",
+		endl: str | None = '\n',
 		clear_screen: bool = False,
 	) -> None:
 		if clear_screen:
-			os.system("clear")
+			os.system('clear')
 
 		if Tui._t is None:
 			print(text, end=endl)
@@ -1336,7 +1333,7 @@ class Tui:
 			return Tui.t()._main_loop(component)
 
 	def _sig_win_resize(self, signum: int, frame: FrameType | None) -> None:
-		if hasattr(self, "_component") and self._component is not None:  # pylint: disable=no-member
+		if hasattr(self, '_component') and self._component is not None:  # pylint: disable=no-member
 			self._component.resize_win()  # pylint: disable=no-member
 
 	def _main_loop[ValueT](self, component: AbstractCurses[ValueT]) -> Result[ValueT]:
@@ -1344,7 +1341,7 @@ class Tui:
 		return component.kickoff(self._screen)
 
 	def _reset_terminal(self) -> None:
-		os.system("reset")
+		os.system('reset')
 
 	def _set_up_colors(self) -> None:
 		curses.init_pair(STYLE.NORMAL.value, curses.COLOR_WHITE, curses.COLOR_BLACK)
